@@ -16,7 +16,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 **************************************************************************** */
 #include "kcubewidget.h"
@@ -243,7 +243,7 @@ void KCubeWidget::mouseReleaseEvent(QMouseEvent *e)
   if(e->button() == LeftButton && _clicksAllowed)
   {
     stopHint();
-    emit clicked(row(),column());
+    emit clicked(row(),column(),true);
   }
 }
 
