@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <qbitmap.h>
@@ -74,7 +74,7 @@ void Level::createRoom()
 
 void Level::makeImageFromData(const uchar *buf)
 {
-	QBitmap bitmap(BoardWidth, BoardWidth, buf, TRUE);
+	QBitmap bitmap(BoardWidth, BoardWidth, buf, true);
 	QImage image = bitmap.convertToImage();
 	initBoard (image);
 }
@@ -123,7 +123,7 @@ void Level::createBanner()
 
 void Level::drawNumber(int beginAt, const uchar *buf)
 {
-	QBitmap bitmap(7, 9, buf, TRUE);
+	QBitmap bitmap(7, 9, buf, true);
 	QImage image = bitmap.convertToImage();
 
 	int index = beginAt;
