@@ -15,28 +15,29 @@
  *                                                                         *
  ***************************************************************************/
 
-// include files for Qt
-#include <stdio.h>
+#include "kwin4view.h"
 
-#include <klocale.h>
+#include <stdio.h>
 #include <math.h>
 
-// application specific includes
-#include "kwin4view.h"
+#include <kconfig.h>
+#include <klocale.h>
+#include <kapplication.h>
+#include <kstandarddirs.h>
+
 #include "kwin4doc.h"
-#include "kwin4.h"
-#include "geom.h"
 #include "scorewidget.h"
 #include "statuswidget.h"
+#include "kspritecache.h"
 
+#include <qlabel.h>
+#include <qlcdnumber.h>
 
-
-// lightGray
-#define COL_STATUSBORDER black
-//#define COL_STATUSFIELD  lightGray
+#define COL_STATUSLIGHT  QColor(210,210,255)
 #define COL_STATUSFIELD  QColor(130,130,255)
 #define COL_STATUSDARK   QColor(0,0,65)
-#define COL_STATUSLIGHT  QColor(210,210,255)
+
+#define COL_STATUSBORDER black
 #define COL_PLAYER       QColor(255,255,0)
 #define COL_RED          red
 #define COL_YELLOW       yellow
@@ -88,25 +89,40 @@ class KIntroMove : public KSpriteMove
 
     return true;
   }
+
   void setDir(bool d) {dir=d;}
-  private:
+
+private:
+
   bool dir;
   int mode;
   int cnt;
   double cx,cy;
+
 };
 
-
-
-Kwin4View::Kwin4View(QString grafixdir,QWidget *parent, const char *name)
-        : QCanvasView(0,parent, name)
-
+Kwin4View::Kwin4View(Kwin4Doc *theDoc, QWidget *parent, const char *name)
+        : QCanvasView(0,parent, name), doc(theDoc)
 {
   mLastArrow=-1;
 
 
-  mGrafix=grafixdir;
-  kdDebug() << "Kwin4View:: grafixdir=" << grafixdir << endl;
+  // localise data file
+  QString file="kwin4/grafix/default/grafix.rc";
+  QString mGrafix=kapp->dirs()->findResourceDir("data",file);
+  if (mGrafix.isNull())
+    mGrafix="grafix/default/";
+  else
+    mGrafix+="kwin4/grafix/default/";
+  if (global_debug>3)
+    kdDebug(12010) << "Localised grafix dir " << mGrafix << endl;
+
+  // Allow overriding of the grafix directory
+  // This is a cheap and dirty way for theming
+  kapp->config()->setGroup("Themes");
+  mGrafix = kapp->config()->readPathEntry("grafixdir", mGrafix);
+
+  
   setVScrollBarMode(AlwaysOff);
   setHScrollBarMode(AlwaysOff);
 
@@ -123,7 +139,6 @@ Kwin4View::Kwin4View(QString grafixdir,QWidget *parent, const char *name)
   mCache->setCanvas(mCanvas);
   KConfig *config=mCache->config();
 
-
   QPoint pnt;
   config->setGroup("game");
 
@@ -135,6 +150,32 @@ Kwin4View::Kwin4View(QString grafixdir,QWidget *parent, const char *name)
   pnt=config->readPointEntry("statuswidget");
   mStatusWidget=new StatusWidget(this);
   mStatusWidget->move(pnt);
+  QPalette pal;
+  pal.setColor(QColorGroup::Light, COL_STATUSLIGHT);
+  pal.setColor(QColorGroup::Mid, COL_STATUSFIELD);
+  pal.setColor(QColorGroup::Dark, COL_STATUSDARK);
+  mStatusWidget->setPalette(pal); 
+  mStatusWidget->setBackgroundColor(COL_STATUSFIELD);
+
+  mStatusWidget->wins->setBackgroundColor(COL_STATUSFIELD);
+  mStatusWidget->draws->setBackgroundColor(COL_STATUSFIELD);
+  mStatusWidget->loses->setBackgroundColor(COL_STATUSFIELD);
+  mStatusWidget->num->setBackgroundColor(COL_STATUSFIELD);
+  mStatusWidget->bk->setBackgroundColor(COL_STATUSFIELD);
+
+  mStatusWidget->p1_name->setBackgroundColor(COL_STATUSFIELD);
+  mStatusWidget->p1_w->setBackgroundColor(COL_STATUSFIELD);
+  mStatusWidget->p1_d->setBackgroundColor(COL_STATUSFIELD);
+  mStatusWidget->p1_l->setBackgroundColor(COL_STATUSFIELD);
+  mStatusWidget->p1_n->setBackgroundColor(COL_STATUSFIELD);
+  mStatusWidget->p1_b->setBackgroundColor(COL_STATUSFIELD);
+
+  mStatusWidget->p2_name->setBackgroundColor(COL_STATUSFIELD);
+  mStatusWidget->p2_w->setBackgroundColor(COL_STATUSFIELD);
+  mStatusWidget->p2_d->setBackgroundColor(COL_STATUSFIELD);
+  mStatusWidget->p2_l->setBackgroundColor(COL_STATUSFIELD);
+  mStatusWidget->p2_n->setBackgroundColor(COL_STATUSFIELD);
+  mStatusWidget->p2_b->setBackgroundColor(COL_STATUSFIELD);
 
   mScoreWidget->hide();
   mStatusWidget->hide();
@@ -143,25 +184,6 @@ Kwin4View::Kwin4View(QString grafixdir,QWidget *parent, const char *name)
   adjustSize();
 
   initView(false);  
-
-  // setBackgroundPixmap( getDocument()->m_PixBackground );
-  //setBackground( getDocument()->m_PixBackground );
-}
-
-
-
-Kwin4View::~Kwin4View()
-{
-  if (mCanvas) delete mCanvas;
-  if (mCache) delete mCache;
-
-}
-
-Kwin4Doc *Kwin4View::getDocument() const
-{
-  Kwin4App *theApp=(Kwin4App *) parentWidget();
-
-  return theApp->getDocument();
 }
 
 void Kwin4View::initView(bool deleteall)
@@ -174,14 +196,16 @@ void Kwin4View::initView(bool deleteall)
   config->setGroup("game");
   mSpreadX=config->readNumEntry("spread_x",0);
   mSpreadY=config->readNumEntry("spread_y",0);
-  //kdDebug() << "Spread : x=" << mSpreadX << " y=" << mSpreadY << endl;
+  //kdDebug(12010) << "Spread : x=" << mSpreadX << " y=" << mSpreadY << endl;
 
   QPixmap *pixmap=loadPixmap("background.png");
-  if (pixmap) mCanvas->setBackgroundPixmap(*pixmap);
-  else mCanvas->setBackgroundColor(QColor(0,0,128));
+  if (pixmap)
+    mCanvas->setBackgroundPixmap(*pixmap);
+  else
+    mCanvas->setBackgroundColor(QColor(0,0,128));
   delete pixmap;
 
-  if (getDocument()->IsIntro())
+  if (doc->gameStatus()==KGame::Intro)
   {
     mScoreWidget->hide();
     mStatusWidget->hide();
@@ -190,7 +214,7 @@ void Kwin4View::initView(bool deleteall)
   else
   {
     // TODO in start functions to distinguish from intro
-    kdDebug() << "Clearing board !!!!!!!!!!"<<endl;
+    kdDebug(12010) << "Clearing board" <<endl;
     drawBoard(deleteall);
     mScoreWidget->show();
     mStatusWidget->show();
@@ -227,10 +251,14 @@ void Kwin4View::initView(bool deleteall)
 
 QPixmap *Kwin4View::loadPixmap(QString name)
 {
-  if (!mCache) return 0;
+  if (!mCache)
+    return 0;
   return mCache->loadPixmap(name);
 }
 
+/**
+ * Called by the doc/app to signal the end of the game
+ */
 void Kwin4View::EndGame()
 {
   KSprite *sprite;
@@ -238,7 +266,7 @@ void Kwin4View::EndGame()
   KConfig *config=mCache->config();
   int dest=config->readNumEntry("destY",150);
   int src=config->readNumEntry("y",0);
-  //kdDebug() << "MOVING gameover to " << dest << endl;
+  //kdDebug(12010) << "MOVING gameover to " << dest << endl;
 
   if (sprite)
   {
@@ -248,7 +276,9 @@ void Kwin4View::EndGame()
   }
 }
 
-// -------------- Draw Sprites ----------------------
+/**
+ * Draw Sprites
+ */
 void Kwin4View::drawStar(int x,int y,int no)
 {
   int dx,dy;
@@ -266,7 +296,7 @@ void Kwin4View::drawStar(int x,int y,int no)
   }
 
   KSprite *sprite=(KSprite *)(mCache->getItem("star",no));
-  //kdDebug() << " setStar("<<x<<","<<y<<","<<no<<") sprite=" << sprite<<endl;
+  //kdDebug(12010) << " setStar("<<x<<","<<y<<","<<no<<") sprite=" << sprite<<endl;
   if (sprite)
   {
     sprite->move(dx/2-sprite->width()/2+x*(dx+mSpreadX)+mBoardX,
@@ -294,6 +324,7 @@ void Kwin4View::hideIntro()
   text=(QCanvasText *)(mCache->getItem("intro3",1));
   if (text) text->hide();
 }
+
 void Kwin4View::drawIntro(bool /*remove*/)
 {
   KSprite *sprite=0;
@@ -362,15 +393,17 @@ void Kwin4View::drawIntro(bool /*remove*/)
       // Carefule: The number must be more then the
       // z coord of [empty] and less than [empty2]
       sprite->setZ(sprite->z()+no/2);
-      // kdDebug() << "Z("<<no<<")="<<sprite->z()<<endl;
+      // kdDebug(12010) << "Z("<<no<<")="<<sprite->z()<<endl;
       sprite->show();
     }
   }
 }
+
+/** 
+ * received after the movment of an intro sprite is finished
+ **/
 void Kwin4View::introMoveDone(QCanvasItem *item,int )
 {
-  //kdDebug() << "########################## INTRO MOVE DONE ################# " << endl;
-
   KSprite *sprite=(KSprite *)item;
   sprite->deleteNotify();
   KIntroMove *move=(KIntroMove *)sprite->moveObject();
@@ -402,7 +435,7 @@ void Kwin4View::drawBoard(bool remove)
     mBoardX=0;
     mBoardY=0;
   }
-      //kdDebug() << "Board X=" << mBoardX << " y="<<mBoardY<<endl;
+      //kdDebug(12010) << "Board X=" << mBoardX << " y="<<mBoardY<<endl;
 
   // Arrows
   for (x=0;x<7;x++)
@@ -476,7 +509,7 @@ void Kwin4View::setPiece(int x,int y,int color,int no,bool animation)
 
   sprite=(KSprite *)(mCache->getItem("piece",no));
 
-  //kdDebug() << " setPiece("<<x<<","<<y<<","<<color<<","<<no<<") sprite=" << sprite<<endl;
+  //kdDebug(12010) << " setPiece("<<x<<","<<y<<","<<color<<","<<no<<") sprite=" << sprite<<endl;
 
   // Check for removal of sprite
   if (color==Niemand)
@@ -499,7 +532,7 @@ void Kwin4View::setPiece(int x,int y,int color,int no,bool animation)
       sprite->moveTo(sprite->x(),
                     sprite->y()+y*(sprite->height()+mSpreadY)+mBoardY);
       connect(sprite->createNotify(),SIGNAL(signalNotify(QCanvasItem *,int)),
-          getDocument(),SLOT(moveDone(QCanvasItem *,int)));
+          doc,SLOT(moveDone(QCanvasItem *,int)));
     }
     else
     {
@@ -509,13 +542,12 @@ void Kwin4View::setPiece(int x,int y,int color,int no,bool animation)
       // Prevent moving (== speed =0)
       sprite->moveTo(sprite->x(),sprite->y());
       connect(sprite->createNotify(),SIGNAL(signalNotify(QCanvasItem *,int)),
-          getDocument(),SLOT(moveDone(QCanvasItem *,int)));
+          doc,SLOT(moveDone(QCanvasItem *,int)));
       sprite->emitNotify(3);
     }
     
     sprite->setFrame(c);
     sprite->show();
-
   }
 }
 
@@ -532,65 +564,72 @@ void Kwin4View::setArrow(int x,int color)
   
   sprite=(KSprite *)(mCache->getItem("arrow",x));
 
-  //kdDebug() << " setArrow("<<x<<","<<color<<") sprite=" << sprite<<endl;
+  //kdDebug(12010) << " setArrow("<<x<<","<<color<<") sprite=" << sprite<<endl;
 
   // Make sure the frames are ok
-  int c;
-  if (color==Gelb) c=1;
-  else if (color==Rot) c=2;
-  else c=0;
+  int c = 0;
+  if (color==Gelb)
+     c=1;
+  else if (color==Rot)
+     c=2;
 
   if (sprite)
-  {
     sprite->setFrame(c);
-  }
   mLastArrow=x;
 }
 
 
-/** Error message if the wrong player moved */
+/**
+ * Error message if the wrong player moved
+ */
 bool Kwin4View::wrongPlayer(KPlayer *player,KGameIO::IOMode io)
 {
-    // Hack to find out whether there is a IO Device whose turn it is
-    KGame::KGamePlayerList *playerList=getDocument()->playerList();
-    KPlayer *p;
+  // Hack to find out whether there is a IO Device whose turn it is
+  KGame::KGamePlayerList *playerList=doc->playerList();
+  KPlayer *p;
 
-    bool flag=false;
-    for ( p=playerList->first(); p!= 0; p=playerList->next() )
-    {
-      if (p==player) continue;
-      if (p->hasRtti(io) && p->myTurn()) flag=true;
-    }
+  bool flag=false;
+  for ( p=playerList->first(); p!= 0; p=playerList->next() )
+  {
+    if (p==player) continue;
+    if (p->hasRtti(io) && p->myTurn()) flag=true;
+  }
 
-    if (flag) return false;
+  if (flag)
+    return false;
     
-    clearError();
-    int rnd=getDocument()->Random(4)+1;
-    QString m;
-    m=QString("text%1").arg(rnd);
-    QString ms;
-    if (rnd==1)      ms=i18n("Hold on... the other player has not been yet..."); 
-    else if (rnd==2) ms=i18n("Hold your horses..."); 
-    else if (rnd==3) ms=i18n("Ah ah ah... only one go at a time..."); 
-    else             ms=i18n("Please wait... it is not your turn."); 
+  clearError();
+  int rnd=(kapp->random()%4) +1;
+  QString m;
+  m=QString("text%1").arg(rnd);
+  QString ms;
+  if (rnd==1)      ms=i18n("Hold on... the other player has not been yet..."); 
+  else if (rnd==2) ms=i18n("Hold your horses..."); 
+  else if (rnd==3) ms=i18n("Ah ah ah... only one go at a time..."); 
+  else             ms=i18n("Please wait... it is not your turn."); 
 
-    // TODO MH can be unique
-    QCanvasText *text=(QCanvasText *)(mCache->getItem(m,1));
-    if (text)
-    {
-      text->setText(ms);
-      text->show();
-    }
-    return true;
+  // TODO MH can be unique
+  QCanvasText *text=(QCanvasText *)(mCache->getItem(m,1));
+  if (text)
+  {
+    text->setText(ms);
+    text->show();
+  }
+  return true;
 }
 
+/**
+ * This slot is called when a key event is received. It then prduces a
+ * valid move for the game.
+ **/
 // This is analogous to the mouse event only it is called when a key is
 // pressed
 void Kwin4View::slotKeyInput(KGameIO *input,QDataStream &stream,QKeyEvent *e,bool *eatevent)
 {
   // Ignore non running
-  if (!getDocument()->isRunning()) return;
-  // kdDebug() << "KEY EVENT" << e->ascii() << endl;
+  if (!doc->isRunning())
+    return;
+  // kdDebug(12010) << "KEY EVENT" << e->ascii() << endl;
 
   // Ignore non key press
   if (e->type() != QEvent::KeyPress) return ;
@@ -606,7 +645,7 @@ void Kwin4View::slotKeyInput(KGameIO *input,QDataStream &stream,QKeyEvent *e,boo
   int code=e->ascii();
   if (code<'1' || code>'7')
   {
-    //kdDebug() << "Key not supported\n";
+    //kdDebug(12010) << "Key not supported\n";
     return ;
   }
 
@@ -618,21 +657,20 @@ void Kwin4View::slotKeyInput(KGameIO *input,QDataStream &stream,QKeyEvent *e,boo
   *eatevent=true;
 }
 
-
-
-// This slot is called when a mouse key is pressed. As the mouse is used as input for all players
-// this slot is called to generate a player move out of a mouse input, i.e.
-// it converts a QMouseEvent into a move for the game. We do here some simple nonsense
-// and use the position of the mouse to generate
-// moves containing the keycodes
+/**
+ * This slot is called when a mouse key is pressed. As the mouse is used as
+ * input for all players
+ * this slot is called to generate a player move out of a mouse input, i.e.
+ * it converts a QMouseEvent into a move for the game. We do here some
+ * simple nonsense and use the position of the mouse to generate
+ * moves containing the keycodes
+ */
 void Kwin4View::slotMouseInput(KGameIO *input,QDataStream &stream,QMouseEvent *mouse,bool *eatevent)
 {
   // Only react to key pressed not released
   if (mouse->type() != QEvent::MouseButtonPress ) return ;
-  if (!getDocument()->isRunning())
-  {
+  if (!doc->isRunning())
     return;
-  }
 
   // Our player
   KPlayer *player=input->player();
@@ -643,19 +681,19 @@ void Kwin4View::slotMouseInput(KGameIO *input,QDataStream &stream,QMouseEvent *m
   }
 
   if (mouse->button()!=LeftButton) return ;
-  //if (!getDocument()->IsRunning()) return ;
+  //if (!doc->IsRunning()) return ;
 
   QPoint point;
   int x,y;
 
-  point=mouse->pos()-geom.field_origin-geom.field_offset;
+  point=mouse->pos() - QPoint(15,40) - QPoint(20,20);
   if (point.x()<0) return ;
 
-  x=point.x()/geom.field_dx;
-  y=point.y()/geom.field_dx;
+  x=point.x()/FIELD_SPACING;
+  y=point.y()/FIELD_SPACING;
 
-  if (y>=geom.field_my) return ;
-  if (x<0 || x>=geom.field_mx) return;
+  if (y>=FIELD_SIZE_Y) return ;
+  if (x<0 || x>=FIELD_SIZE_X) return;
 
   // Create a move
   Q_INT32 move,pl;
@@ -663,9 +701,12 @@ void Kwin4View::slotMouseInput(KGameIO *input,QDataStream &stream,QMouseEvent *m
   pl=player->userId();
   stream << pl << move;
   *eatevent=true;
-  // kdDebug() << "Mouse input done..eatevent=true" << endl;
+  // kdDebug(12010) << "Mouse input done..eatevent=true" << endl;
 }
 
+/**
+ * Hide all the error sprites
+ */ 
 void Kwin4View::clearError()
 {
   QCanvasText *text;
